<?php
/** 
*
* @package DM Partners
* @version $Id: install_dm_partners.php 19 2010-08-08 14:14:02Z femu $
* @copyright (c) 2009 femu - http://die-muellers.org
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* @ignore
*/
define('UMIL_AUTO', true);
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup();

if (!file_exists($phpbb_root_path . 'umil/umil_auto.' . $phpEx))
{
	trigger_error('Please download the latest UMIL (Unified MOD Install Library) from: <a href="http://www.phpbb.com/mods/umil/">phpBB.com/mods/umil</a>', E_USER_ERROR);
}

// The name of the mod to be displayed during installation.
$mod_name = 'INSTALL_NAME';

/*
* The name of the config variable which will hold the currently installed version
* You do not need to set this yourself, UMIL will handle setting and updating the version itself.
*/
$version_config_name = 'dm_partners_version';

/*
* The language file which will be included when installing
* Language entries that should exist in the language file for UMIL (replace $mod_name with the mod's name you set to $mod_name above)
*/
$language_file = 'mods/dm_partners';

/*
* The array of versions and actions within each.
* You do not need to order it a specific way (it will be sorted automatically), however, you must enter every version, even if no actions are done for it.
*
* You must use correct version numbering.  Unless you know exactly what you can use, only use X.X.X (replacing X with an integer).
* The version numbering must otherwise be compatible with the version_compare function - http://php.net/manual/en/function.version-compare.php
*/

/**
* Define the basic structure
* The format:
*		array('{TABLE_NAME}' => {TABLE_DATA})
*		{TABLE_DATA}:
*			COLUMNS = array({column_name} = array({column_type}, {default}, {auto_increment}))
*			PRIMARY_KEY = {column_name(s)}
*			KEYS = array({key_name} = array({key_type}, {column_name(s)})),
*
*	Column Types:
*	INT:x		=> SIGNED int(x)
*	BINT		=> BIGINT
*	UINT		=> mediumint(8) UNSIGNED
*	UINT:x		=> int(x) UNSIGNED
*	TINT:x		=> tinyint(x)
*	USINT		=> smallint(4) UNSIGNED (for _order columns)
*	BOOL		=> tinyint(1) UNSIGNED
*	VCHAR		=> varchar(255)
*	CHAR:x		=> char(x)
*	XSTEXT_UNI	=> text for storing 100 characters (topic_title for example)
*	STEXT_UNI	=> text for storing 255 characters (normal input field with a max of 255 single-byte chars) - same as VCHAR_UNI
*	TEXT_UNI	=> text for storing 3000 characters (short text, descriptions, comments, etc.)
*	MTEXT_UNI	=> mediumtext (post text, large text)
*	VCHAR:x		=> varchar(x)
*	TIMESTAMP	=> int(11) UNSIGNED
*	DECIMAL		=> decimal number (5,2)
*	DECIMAL:		=> decimal number (x,2)
*	PDECIMAL		=> precision decimal number (6,3)
*	PDECIMAL:	=> precision decimal number (x,3)
*	VCHAR_UNI	=> varchar(255) BINARY
*	VCHAR_CI		=> varchar_ci for postgresql, others VCHAR
*/

$versions = array(
	// Version 1.0.0 - this is the first version using UMIL
	//all older versions have to add the config variable 'f1webtipp_version' with the value '0.3.0' before.
	//See also the update instructions -->  /contrib/update_0130_to_030.xml
	'1.0.0'	=> array(
		// Now to add the tables (this uses the layout from develop/create_schema_files.php and from phpbb_db_tools)
		'table_add' => array(
			array($table_prefix . 'dm_partners', array(
					'COLUMNS'		=> array(
						'id'				=> array('UINT:10', NULL, 'auto_increment'),
						'creator_id'		=> array('UINT:10', 0),
						'title'				=> array('MTEXT_UNI', ''),
						'url'				=> array('VCHAR', ''),
						'image_url'			=> array('VCHAR', ''),
						'counter'			=> array('UINT:10', 0),
						'text'				=> array('MTEXT_UNI', ''),
						'bbcode_bitfield'	=> array('VCHAR', ''),
						'bbcode_uid'		=> array('VCHAR:8', ''),
						'enable_bbcode'		=> array('BOOL', 0),
						'enable_smilies'	=> array('BOOL', 0),
						'enable_magic_url'	=> array('BOOL', 0),
						'enable_count'		=> array('BOOL', 0),
						'activ'				=> array('BOOL', 0),
					),
					'PRIMARY_KEY'	=> 'id',
				),
			),
		),

		// Now to add some permission settings
		'permission_add' => array(
			array('a_dm_partners_edit', true),
			array('u_dm_partners_view', true),
			array('u_dm_partners_add', true),
		),

		// How about we give some default permissions then as well?
		'permission_set' => array(
			// Permissions
			array('REGISTERED', 'u_dm_partners_view', 'group'),
			array('REGISTERED', 'u_dm_partners_add', 'group'),
		),

		// Clear the general cache as well as the templates, imagesets and themes cache
		'cache_purge' => array(
        	array(),
        	array('imageset'),
        	array('template'),
        	array('theme'),
        ),

		// Alright, now lets add some modules to the ACP
		'module_add' => array(
			// First, lets add a new category named ACP_DMP_PARTNERS to ACP_CAT_DOT_MODS
			array('acp', 'ACP_CAT_DOT_MODS', 'ACP_DMP_PARTNERS'),

			// Now we will add the settings mode to the ACP_PARTNERS category
            array('acp', 'ACP_DMP_PARTNERS', array(
					'module_basename'	=> 'dm_partners',
					'module_langname'	=> 'ACP_DMP_CONFIG',
					'module_mode'		=> 'acp_dmp_config',
					'module_auth'		=> 'acl_a_dm_partners_edit',
				),
			),
		),

		/*
		* Now we need to insert some data.  The easiest way to do that is through a custom function
		* Enter 'custom' for the array key and the name of the function for the value.
		*/
		'custom'	=> 'first_fill_1_0_0',
	),

	// Version 1.0.1 - Update version only
	'1.0.1'	=> array(),

	// Version 1.0.2 - Update version only
	'1.0.2'	=> array(),

	// Version 1.0.3 - Update version only
	'1.0.3'	=> array(),

	// Version 1.0.4 - Added standard admin role
	'1.0.4'	=> array(
		// How about we give some default permissions then as well?
		'permission_set' => array(
			// Permissions
			array('ROLE_ADMIN_STANDARD', 'a_dm_partners_edit', 'role'),
			array('ROLE_ADMIN_STANDARD', 'u_dm_partners_view', 'role'),
			array('ROLE_ADMIN_STANDARD', 'u_dm_partners_add', 'role'),
			array('GUESTS', 'u_dm_partners_view', 'group'),
		),
	),
);

// Include the UMIF Auto file and everything else will be handled automatically.
include($phpbb_root_path . 'umil/umil_auto.' . $phpEx);

/*
* Here is our custom function that will be called for version 0.3.0.
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function first_fill_1_0_0($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
			// Run this when installing the first time
			if ($umil->table_exists($table_prefix . 'config'))
			{
				$sql_ary = array();

				$sql_ary[] = array('config_name' => 'dm_partners_new', 'config_value' => '1',);
				$db->sql_multi_insert($table_prefix . 'config ', $sql_ary);
			}
			return 'INSTALL_INSERT_FIRST_FILL';
		break;

		case 'update' :
		break;

 		case 'uninstall' :
			// Run this additionally when uninstalling
			if ($umil->table_exists($table_prefix . 'config'))
			{
				$sql = 'DELETE FROM ' . $table_prefix . "config
					WHERE config_name = 'dm_partners_new'";
				$db->sql_query($sql);

				// Send the message, that the command was successful
				return 'INSTALL_REMOVE_CONFIG_ENTRIES';
			}
		break;
	}
}

?>